<template>
  <el-header height="48px">
    <el-row>
      <el-col :span="6">
        <a class="logo-link">
          <img :src="require('../assets/artLogo.png')"
            alt="artLogo"
            class="nav-logo"
          />
          ARTFESS
        </a>
      </el-col>
      <el-col :span="18">
        <div class="nav-more">
          <el-autocomplete
            popper-class="my-autocomplete"
            size="small"
            class="inline-input"
            v-model="searchWork"
            :fetch-suggestions="querySearch"
            placeholder="搜索组件"
            :trigger-on-focus="false"
            @select="handleSelect"
          >
            <template slot-scope="{ item }">
              <div class="index">{{ item.index }}</div>
              <span class="label">{{ item.label }}</span>
            </template>
          </el-autocomplete>
          <!-- <el-divider direction="vertical"></el-divider>
          <span>指南</span>
          <el-divider direction="vertical"></el-divider>
          <span class="active">组件</span>
          <el-divider direction="vertical"></el-divider>
          <span>资源</span>
          <el-divider direction="vertical"></el-divider>
          <el-dropdown size="small" split-button type="default">
            {{version}}
            <el-dropdown-menu slot="dropdown">
              <el-dropdown-item>{{version}}</el-dropdown-item>
            </el-dropdown-menu>
          </el-dropdown> -->
          <el-divider direction="vertical"></el-divider>
          <lang-select class="right-menu-item hover-effect" />
        </div>
      </el-col>
    </el-row>
  </el-header>
</template>

<script>
import menu from "@/api/menu.js";
import LangSelect from "@/components/langSelect/LangSelect.vue";
import HotentUi from "@/components/index";

export default {
  name: "navigator",
  components: { LangSelect },
  data() {
    return {
      menus: [],
      searchWork: "",
      version: HotentUi.version,
    };
  },
  methods: {
    querySearch(queryString, cb) {
      var menus = this.menus;
      var results = queryString
        ? menus.filter(this.createFilter(queryString))
        : menus;
      // 调用 callback 返回建议列表的数据
      cb(results);
    },
    createFilter(queryString) {
      return menu => {
        return (
          menu.index.toLowerCase().indexOf(queryString.toLowerCase()) != -1 ||
          menu.label.toLowerCase().indexOf(queryString.toLowerCase()) != -1
        );
      };
    },
    handleSelect(item) {
      this.$router.push({ path: `/${item.index}` });
      // window.location.href = item.index;
    }
  },
  mounted() {
    menu.getComponentMenus(menus => {
      this.menus = menus;
    });
  }
};
</script>

<style lang="scss" scoped>
.el-header {
  line-height: 48px;
  color: #555;
  background: #FFF;
  -moz-box-shadow: 1px 1px 1px #DDD;
  box-shadow: 1px 1px 1px #DDD;
}

.logo-link {
  margin-left: 30px;
  font-weight: bold;
  font-size: 18px;
  color: #2274AF;
  text-decoration: none;
}

.nav-logo {
  width: 40px;
  height: 25px;
  line-height: 25px;
  vertical-align: middle;
  margin-top: -6px;
}

.nav-more {
  float: right;
  margin-right: 30px;
}

.nav-more .el-divider {
  margin-left: 20px;
  margin-right: 20px;
}

.nav-more span {
  font-weight: bold;
  font-size: 13px;
  cursor: pointer;
}

.nav-more span.active {
  padding-top: 13px;
  border-top: 2px solid #2274AF;
  color: #2274AF;
}

.my-autocomplete {
  li {
    line-height: normal;
    padding: 7px;

    .index {
      text-overflow: ellipsis;
      overflow: hidden;
    }

    .label {
      font-size: 12px;
      color: #b4b4b4;
    }

    .highlighted .index {
      color: #ddd;
    }
  }
}
</style>
